@@ -8,6 +8,10 @@
 
 G_BEGIN_DECLS
 
+/* enumerations from "oobs-error.h" */
+GType oobs_error_get_type (void) G_GNUC_CONST;
+#define OOBS_TYPE_ERROR (oobs_error_get_type())
+
 /* enumerations from "oobs-share-smb.h" */
 GType oobs_share_smb_flags_get_type (void) G_GNUC_CONST;
 #define OOBS_TYPE_SHARE_SMB_FLAGS (oobs_share_smb_flags_get_type())
