@@ -28,6 +28,13 @@
 #include "oobs-statichost.h"
 #include "utils.h"
 
+/**
+ * SECTION:oobs-hostsconfig
+ * @title: OobsHostsConfig
+ * @short_description: Object that represents hosts resolution configuration
+ * @see_also: #OobsStaticHost
+ **/
+
 #define HOSTS_CONFIG_REMOTE_OBJECT "HostsConfig"
 #define OOBS_HOSTS_CONFIG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), OOBS_TYPE_HOSTS_CONFIG, OobsHostsConfigPrivate))
 
@@ -282,9 +289,14 @@ oobs_hosts_config_commit (OobsObject *object)
 OobsObject*
 oobs_hosts_config_get (void)
 {
-  return g_object_new (OOBS_TYPE_HOSTS_CONFIG,
-		       "remote-object", HOSTS_CONFIG_REMOTE_OBJECT,
-		       NULL);
+  static OobsObject *the_object = NULL;
+
+  if (!the_object)
+    the_object = g_object_new (OOBS_TYPE_HOSTS_CONFIG,
+                               "remote-object", HOSTS_CONFIG_REMOTE_OBJECT,
+                               NULL);
+
+  return the_object;
 }
 
 /**
