@@ -18,10 +18,15 @@
  * Authors: Carlos Garnacho Parro  <carlosg@gnome.org>
  */
 
+#include "config.h"
 #include <dbus/dbus.h>
 #include <glib-object.h>
-#include <libhal.h>
 #include <string.h>
+
+#ifdef HAVE_HAL
+#include <libhal.h>
+#endif
+
 #include "oobs-session-private.h"
 #include "oobs-list-private.h"
 #include "oobs-object-private.h"
@@ -33,7 +38,6 @@
 #include "oobs-iface-ppp.h"
 #include "iface-state-monitor.h"
 #include "utils.h"
-#include "config.h"
 
 /**
  * SECTION:oobs-ifacesconfig
@@ -296,7 +300,7 @@ oobs_ifaces_config_finalize (GObject *object)
     (* G_OBJECT_CLASS (oobs_ifaces_config_parent_class)->finalize) (object);
 }
 
-GObject*
+static GObject*
 create_iface_from_message (DBusMessage     *message,
 			   DBusMessageIter *iter,
 			   gint             type,
@@ -798,9 +802,14 @@ oobs_ifaces_config_commit (OobsObject *object)
 OobsObject*
 oobs_ifaces_config_get (void)
 {
-  return g_object_new (OOBS_TYPE_IFACES_CONFIG,
-		       "remote-object", IFACES_CONFIG_REMOTE_OBJECT,
-		       NULL);
+  static OobsObject *the_object = NULL;
+
+  if (!the_object)
+    the_object = g_object_new (OOBS_TYPE_IFACES_CONFIG,
+                               "remote-object", IFACES_CONFIG_REMOTE_OBJECT,
+                               NULL);
+
+  return the_object;
 }
 
 /**
