@@ -28,6 +28,13 @@
 #include "oobs-ntpserver.h"
 #include "utils.h"
 
+/**
+ * SECTION:oobs-ntpconfig
+ * @title: OobsNTPConfig
+ * @short_description: Object that represents NTP configuration
+ * @see_also: #OobsNTPServer, #OobsTimeConfig
+ **/
+
 #define NTP_CONFIG_REMOTE_OBJECT "NTPConfig"
 #define OOBS_NTP_CONFIG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), OOBS_TYPE_NTP_CONFIG, OobsNTPConfigPrivate))
 
@@ -170,9 +177,14 @@ oobs_ntp_config_commit (OobsObject *object)
 OobsObject*
 oobs_ntp_config_get (void)
 {
-  return g_object_new (OOBS_TYPE_NTP_CONFIG,
-		       "remote-object", NTP_CONFIG_REMOTE_OBJECT,
-		       NULL);
+  static OobsObject *the_object = NULL;
+
+  if (!the_object)
+    the_object = g_object_new (OOBS_TYPE_NTP_CONFIG,
+                               "remote-object", NTP_CONFIG_REMOTE_OBJECT,
+                               NULL);
+
+  return the_object;
 }
 
 /**
